@@ -1,5 +1,5 @@
 package Net::Whois::Raw::Data;
-$Net::Whois::Raw::Data::VERSION = '2.89';
+$Net::Whois::Raw::Data::VERSION = '2.90';
 # ABSTRACT: Config for Net::Whois::Raw.
 
 use utf8;
@@ -715,6 +715,13 @@ our %servers = qw(
     THEATRE     whois.centralnic.com
     TICKETS     whois.centralnic.com
     WEBSITE     whois.centralnic.com
+    BAR         whois.centralnic.com
+    COLLEGE     whois.centralnic.com
+    FEEDBACK    whois.centralnic.com
+    INK         whois.centralnic.com
+    REST        whois.centralnic.com
+    WIKI        whois.centralnic.com
+    XYZ         whois.centralnic.com
 
     ORG.NS      whois.pir.org
     BIZ.NS      whois.biz
@@ -2592,7 +2599,7 @@ Net::Whois::Raw::Data - Config for Net::Whois::Raw.
 
 =head1 VERSION
 
-version 2.89
+version 2.90
 
 =head1 AUTHOR
 
